@@ -154,15 +154,23 @@ class PMA_NavigationTree
     {
         $retval = 0;
         if (! empty($GLOBALS['db'])) {
-            $query  = "SELECT (COUNT(`SCHEMA_NAME`) DIV %d) * %d ";
-            $query .= "FROM `INFORMATION_SCHEMA`.`SCHEMATA` ";
-            $query .= "WHERE `SCHEMA_NAME` < '%s' ";
-            $query .= "ORDER BY `SCHEMA_NAME` ASC";
+            /*
+             * @todo describe a scenario where this code is executed
+             */
+            $query  = "SELECT (COUNT(DB_first_level) DIV %d) * %d ";
+            $query .= "from ( ";
+            $query .= " SELECT distinct SUBSTRING_INDEX(SCHEMA_NAME, ";
+            $query .= " '{$GLOBALS['cfg']['NavigationTreeDbSeparator']}', 1) ";
+            $query .= " DB_first_level ";
+            $query .= " FROM INFORMATION_SCHEMA.SCHEMATA ";
+            $query .= " WHERE `SCHEMA_NAME` < '%s' ";
+            $query .= ") t ";
+
             $retval = $GLOBALS['dbi']->fetchValue(
                 sprintf(
                     $query,
-                    (int)$GLOBALS['cfg']['MaxNavigationItems'],
-                    (int)$GLOBALS['cfg']['MaxNavigationItems'],
+                    (int)$GLOBALS['cfg']['FirstLevelNavigationItems'],
+                    (int)$GLOBALS['cfg']['FirstLevelNavigationItems'],
                     PMA_Util::sqlAddSlashes($GLOBALS['db'])
                 )
             );
@@ -239,144 +247,153 @@ class PMA_NavigationTree
     private function _buildPathPart($path, $type2, $pos2, $type3, $pos3)
     {
         $retval = true;
-        if (count($path) > 1) {
-            array_shift($path); // remove 'root'
-            $db = $this->_tree->getChild($path[0]);
-            $retval = $db;
+        if (count($path) <= 1) {
+            return $retval;
+        }
 
-            if ($db === false) {
+        array_shift($path); // remove 'root'
+        $db = $this->_tree->getChild($path[0]);
+        $retval = $db;
+
+        if ($db === false) {
+            return false;
+        }
+
+        $containers = $this->_addDbContainers($db, $type2, $pos2);
+
+        array_shift($path); // remove db
+
+        if ((count($path) <= 0
+            || !array_key_exists($path[0], $containers))
+            && count($containers) != 1
+        ) {
+            return $retval;
+        }
+
+        if (count($containers) == 1) {
+            $container = array_shift($containers);
+        } else {
+            $container = $db->getChild($path[0], true);
+            if ($container === false) {
                 return false;
             }
+        }
+        $retval = $container;
 
-            $containers = $this->_addDbContainers($db, $type2, $pos2);
-
-            array_shift($path); // remove db
-
-            if ((count($path) > 0
-                && array_key_exists($path[0], $containers))
-                || count($containers) == 1
-            ) {
-                if (count($containers) == 1) {
-                    $container = array_shift($containers);
-                } else {
-                    $container = $db->getChild($path[0], true);
-                    if ($container === false) {
-                        return false;
-                    }
-                }
-                $retval = $container;
-
-                if (count($container->children) <= 1) {
-                    $dbData = $db->getData(
-                        $container->real_name,
-                        $pos2,
-                        $this->_searchClause2
+        if (count($container->children) <= 1) {
+            $dbData = $db->getData(
+                $container->real_name,
+                $pos2,
+                $this->_searchClause2
+            );
+            foreach ($dbData as $item) {
+                switch ($container->real_name) {
+                case 'events':
+                    $node = PMA_NodeFactory::getInstance(
+                        'Node_Event',
+                        $item
                     );
-                    foreach ($dbData as $item) {
-                        switch ($container->real_name) {
-                        case 'events':
-                            $node = PMA_NodeFactory::getInstance(
-                                'Node_Event',
-                                $item
-                            );
-                            break;
-                        case 'functions':
-                            $node = PMA_NodeFactory::getInstance(
-                                'Node_Function',
-                                $item
-                            );
-                            break;
-                        case 'procedures':
-                            $node = PMA_NodeFactory::getInstance(
-                                'Node_Procedure',
-                                $item
-                            );
-                            break;
-                        case 'tables':
-                            $node = PMA_NodeFactory::getInstance(
-                                'Node_Table',
-                                $item
-                            );
-                            break;
-                        case 'views':
-                            $node = PMA_NodeFactory::getInstance(
-                                'Node_View',
-                                $item
-                            );
-                            break;
-                        default:
-                            break;
-                        }
-                        if (isset($node)) {
-                            if ($type2 == $container->real_name) {
-                                $node->pos2 = $pos2;
-                            }
-                            $container->addChild($node);
-                        }
-                    }
+                    break;
+                case 'functions':
+                    $node = PMA_NodeFactory::getInstance(
+                        'Node_Function',
+                        $item
+                    );
+                    break;
+                case 'procedures':
+                    $node = PMA_NodeFactory::getInstance(
+                        'Node_Procedure',
+                        $item
+                    );
+                    break;
+                case 'tables':
+                    $node = PMA_NodeFactory::getInstance(
+                        'Node_Table',
+                        $item
+                    );
+                    break;
+                case 'views':
+                    $node = PMA_NodeFactory::getInstance(
+                        'Node_View',
+                        $item
+                    );
+                    break;
+                default:
+                    break;
                 }
-                if (count($path) > 1 && $path[0] != 'tables') {
-                    $retval = false;
-                } else {
-                    array_shift($path); // remove container
-                    if (count($path) > 0) {
-                        $table = $container->getChild($path[0], true);
-                        if ($table === false) {
-                            return false;
-                        }
-                        $retval = $table;
-                        $containers = $this->_addTableContainers(
-                            $table,
-                            $pos2,
-                            $type3,
-                            $pos3
-                        );
-                        array_shift($path); // remove table
-                        if (count($path) > 0
-                            && array_key_exists($path[0], $containers)
-                        ) {
-                            $container = $table->getChild($path[0], true);
-                            $retval = $container;
-                            $tableData = $table->getData(
-                                $container->real_name,
-                                $pos3
-                            );
-                            foreach ($tableData as $item) {
-                                switch ($container->real_name) {
-                                case 'indexes':
-                                    $node = PMA_NodeFactory::getInstance(
-                                        'Node_Index',
-                                        $item
-                                    );
-                                    break;
-                                case 'columns':
-                                    $node = PMA_NodeFactory::getInstance(
-                                        'Node_Column',
-                                        $item
-                                    );
-                                    break;
-                                case 'triggers':
-                                    $node = PMA_NodeFactory::getInstance(
-                                        'Node_Trigger',
-                                        $item
-                                    );
-                                    break;
-                                default:
-                                    break;
-                                }
-                                if (isset($node)) {
-                                    $node->pos2 = $container->parent->pos2;
-                                    if ($type3 == $container->real_name) {
-                                        $node->pos3 = $pos3;
-                                    }
-                                    $container->addChild($node);
-                                }
-                            }
-                        }
+                if (isset($node)) {
+                    if ($type2 == $container->real_name) {
+                        $node->pos2 = $pos2;
                     }
+                    $container->addChild($node);
                 }
             }
         }
+        if (count($path) > 1 && $path[0] != 'tables') {
+            $retval = false;
+            return $retval;
+        }
+
+        array_shift($path); // remove container
+        if (count($path) <= 0) {
+            return $retval;
+        }
+
+        $table = $container->getChild($path[0], true);
+        if ($table === false) {
+            return false;
+        }
+        $retval = $table;
+        $containers = $this->_addTableContainers(
+            $table,
+            $pos2,
+            $type3,
+            $pos3
+        );
+        array_shift($path); // remove table
+        if (count($path) <= 0
+            || !array_key_exists($path[0], $containers)
+        ) {
+            return $retval;
+        }
+
+        $container = $table->getChild($path[0], true);
+        $retval = $container;
+        $tableData = $table->getData(
+            $container->real_name,
+            $pos3
+        );
+        foreach ($tableData as $item) {
+            switch ($container->real_name) {
+            case 'indexes':
+                $node = PMA_NodeFactory::getInstance(
+                    'Node_Index',
+                    $item
+                );
+                break;
+            case 'columns':
+                $node = PMA_NodeFactory::getInstance(
+                    'Node_Column',
+                    $item
+                );
+                break;
+            case 'triggers':
+                $node = PMA_NodeFactory::getInstance(
+                    'Node_Trigger',
+                    $item
+                );
+                break;
+            default:
+                break;
+            }
+            if (isset($node)) {
+                $node->pos2 = $container->parent->pos2;
+                if ($type3 == $container->real_name) {
+                    $node->pos3 = $pos3;
+                }
+                $container->addChild($node);
+            }
+        }
         return $retval;
     }
 
@@ -519,7 +536,7 @@ class PMA_NavigationTree
     }
 
     /**
-     * Recursively groups tree nodes given a sperarator
+     * Recursively groups tree nodes given a separator
      *
      * @param Node $node The node to group
      *
@@ -527,106 +544,121 @@ class PMA_NavigationTree
      */
     public function groupNode($node)
     {
-        if ($node->type == Node::CONTAINER) {
-            $separators = array();
-            if (is_array($node->separator)) {
-                $separators = $node->separator;
-            } else if (strlen($node->separator)) {
-                $separators[] = $node->separator;
-            }
-            $prefixes = array();
-            if ($node->separator_depth > 0) {
-                foreach ($node->children as $child) {
-                    $prefix_pos = false;
-                    foreach ($separators as $separator) {
-                        $sep_pos = strpos($child->name, $separator);
-                        if ($sep_pos != false
-                            && $sep_pos != strlen($child->name)
-                            && $sep_pos != 0
-                            && ($prefix_pos == false || $sep_pos < $prefix_pos)
-                        ) {
-                            $prefix_pos = $sep_pos;
-                        }
+        if ($node->type != Node::CONTAINER || $GLOBALS['cfg']['NavigationTreeDisableDatabaseExpansion']) {
+            return;
+        }
+
+        $separators = array();
+        if (is_array($node->separator)) {
+            $separators = $node->separator;
+        } else if (strlen($node->separator)) {
+            $separators[] = $node->separator;
+        }
+        $prefixes = array();
+        if ($node->separator_depth > 0) {
+            foreach ($node->children as $child) {
+                $prefix_pos = false;
+                foreach ($separators as $separator) {
+                    $sep_pos = strpos($child->name, $separator);
+                    if ($sep_pos != false
+                        && $sep_pos != strlen($child->name)
+                        && $sep_pos != 0
+                        && ($prefix_pos == false || $sep_pos < $prefix_pos)
+                    ) {
+                        $prefix_pos = $sep_pos;
                     }
-                    if ($prefix_pos !== false) {
-                        $prefix = substr($child->name, 0, $prefix_pos);
-                        if (! isset($prefixes[$prefix])) {
-                            $prefixes[$prefix] = 1;
-                        } else {
-                            $prefixes[$prefix]++;
+                }
+                if ($prefix_pos !== false) {
+                    $prefix = substr($child->name, 0, $prefix_pos);
+                    if (! isset($prefixes[$prefix])) {
+                        $prefixes[$prefix] = 1;
+                    } else {
+                        $prefixes[$prefix]++;
+                    }
+                }
+                //Bug #4375: Check if prefix is the name of a DB, to create a group.
+                foreach ($node->children as $child) {
+                    if (array_key_exists($child->name, $prefixes)) {
+                        $prefixes[$child->name]++;
+                    }
+                }
+            }
+            //Check if prefix is the name of a DB, to create a group.
+            foreach ($node->children as $child) {
+                if (array_key_exists($child->name, $prefixes)) {
+                    $prefixes[$child->name]++;
+                }
+            }
+        }
+        foreach ($prefixes as $key => $value) {
+            if ($value == 1) {
+                unset($prefixes[$key]);
+            }
+        }
+        if (count($prefixes)) {
+            $groups = array();
+            foreach ($prefixes as $key => $value) {
+                $groups[$key] = new Node(
+                    $key,
+                    Node::CONTAINER,
+                    true
+                );
+                $groups[$key]->separator = $node->separator;
+                $groups[$key]->separator_depth = $node->separator_depth - 1;
+                $groups[$key]->icon = '';
+                if (PMA_Util::showIcons('TableNavigationLinksMode')) {
+                    $groups[$key]->icon = PMA_Util::getImage(
+                        'b_group.png'
+                    );
+                }
+                $groups[$key]->pos2 = $node->pos2;
+                $groups[$key]->pos3 = $node->pos3;
+                if ($node instanceof Node_Table_Container
+                    || $node instanceof Node_View_Container
+                ) {
+                    $tblGroup = '&amp;tbl_group=' . urlencode($key);
+                    $groups[$key]->links = array(
+                        'text' => $node->links['text'] . $tblGroup,
+                        'icon' => $node->links['icon'] . $tblGroup
+                    );
+                }
+                $node->addChild($groups[$key]);
+                foreach ($separators as $separator) {
+                    // FIXME: this could be more efficient
+                    foreach ($node->children as $child) {
+                        $name_substring = substr(
+                            $child->name, 0, strlen($key) + strlen($separator)
+                        );
+                        if (($name_substring != $key . $separator
+                            && $child->name != $key)
+                            || $child->type != Node::OBJECT
+                        ) {
+                            continue;
                         }
+                        $class = get_class($child);
+                        $new_child = PMA_NodeFactory::getInstance(
+                            $class,
+                            substr(
+                                $child->name,
+                                strlen($key) + strlen($separator)
+                            )
+                        );
+                        $new_child->real_name = $child->real_name;
+                        $new_child->icon = $child->icon;
+                        $new_child->links = $child->links;
+                        $new_child->pos2 = $child->pos2;
+                        $new_child->pos3 = $child->pos3;
+                        $groups[$key]->addChild($new_child);
+                        foreach ($child->children as $elm) {
+                            $new_child->addChild($elm);
+                        }
+                        $node->removeChild($child->name);
                     }
                 }
             }
             foreach ($prefixes as $key => $value) {
-                if ($value == 1) {
-                    unset($prefixes[$key]);
-                }
-            }
-            if (count($prefixes)) {
-                $groups = array();
-                foreach ($prefixes as $key => $value) {
-                    $groups[$key] = new Node(
-                        $key,
-                        Node::CONTAINER,
-                        true
-                    );
-                    $groups[$key]->separator = $node->separator;
-                    $groups[$key]->separator_depth = $node->separator_depth - 1;
-                    $groups[$key]->icon = '';
-                    if (PMA_Util::showIcons('TableNavigationLinksMode')) {
-                        $groups[$key]->icon = PMA_Util::getImage(
-                            'b_group.png'
-                        );
-                    }
-                    $groups[$key]->pos2 = $node->pos2;
-                    $groups[$key]->pos3 = $node->pos3;
-                    if ($node instanceof Node_Table_Container
-                        || $node instanceof Node_View_Container
-                    ) {
-                        $tblGroup = '&amp;tbl_group=' . urlencode($key);
-                        $groups[$key]->links = array(
-                            'text' => $node->links['text'] . $tblGroup,
-                            'icon' => $node->links['icon'] . $tblGroup
-                        );
-                    }
-                    $node->addChild($groups[$key]);
-                    foreach ($separators as $separator) {
-                        // FIXME: this could be more efficient
-                        foreach ($node->children as $child) {
-                            $name_substring = substr(
-                                $child->name, 0, strlen($key) + strlen($separator)
-                            );
-                            if (($name_substring == $key . $separator
-                                || $child->name == $key)
-                                && $child->type == Node::OBJECT
-                            ) {
-                                $class = get_class($child);
-                                $new_child = PMA_NodeFactory::getInstance(
-                                    $class,
-                                    substr(
-                                        $child->name,
-                                        strlen($key) + strlen($separator)
-                                    )
-                                );
-                                $new_child->real_name = $child->real_name;
-                                $new_child->icon = $child->icon;
-                                $new_child->links = $child->links;
-                                $new_child->pos2 = $child->pos2;
-                                $new_child->pos3 = $child->pos3;
-                                $groups[$key]->addChild($new_child);
-                                foreach ($child->children as $elm) {
-                                    $new_child->addChild($elm);
-                                }
-                                $node->removeChild($child->name);
-                            }
-                        }
-                    }
-                }
-                foreach ($prefixes as $key => $value) {
-                    $this->groupNode($groups[$key]);
-                    $groups[$key]->classes = "navGroup";
-                }
+                $this->groupNode($groups[$key]);
+                $groups[$key]->classes = "navGroup";
             }
         }
     }
@@ -640,17 +672,19 @@ class PMA_NavigationTree
     public function renderState()
     {
         $this->_buildPath();
-        $retval  = $this->_fastFilterHtml($this->_tree);
+        $retval  = $this->_quickWarp();
+        $retval .= '<div class="clearfloat"></div>';
+        $retval .= $this->_fastFilterHtml($this->_tree);
         $retval .= $this->_getPageSelector($this->_tree);
         $this->groupTree();
         $retval .= "<div id='pma_navigation_tree_content'><ul>";
         $children = $this->_tree->children;
         usort($children, array('PMA_NavigationTree', 'sortNode'));
         $this->_setVisibility();
-        for ($i=0; $i<count($children); $i++) {
+        for ($i=0, $nbChildren = count($children); $i < $nbChildren; $i++) {
             if ($i == 0) {
                 $retval .= $this->_renderNode($children[0], true, 'first');
-            } else if ($i + 1 != count($children)) {
+            } else if ($i + 1 != $nbChildren) {
                 $retval .= $this->_renderNode($children[$i], true);
             } else {
                 $retval .= $this->_renderNode($children[$i], true, 'last');
@@ -679,8 +713,8 @@ class PMA_NavigationTree
             $retval .= $this->_getPageSelector($node);
             $children = $node->children;
             usort($children, array('PMA_NavigationTree', 'sortNode'));
-            for ($i=0; $i<count($children); $i++) {
-                if ($i + 1 != count($children)) {
+            for ($i=0, $nbChildren = count($children); $i < $nbChildren; $i++) {
+                if ($i + 1 != $nbChildren) {
                     $retval .= $this->_renderNode($children[$i], true);
                 } else {
                     $retval .= $this->_renderNode($children[$i], true, 'last');
@@ -805,8 +839,10 @@ class PMA_NavigationTree
             if (count($parents)) {
                 $parentName = $parents[0]->real_name;
             }
+            // if node name itself is in sterile, then allow
             if ($node->is_group
                 || (! in_array($parentName, $sterile) && ! $node->isNew)
+                || (in_array($node->real_name, $sterile))
             ) {
                 $loaded = '';
                 if ($node->is_group) {
@@ -861,7 +897,12 @@ class PMA_NavigationTree
                     }
                 }
 
-                $retval .= "<a class='expander$loaded$container'";
+                if (! $GLOBALS['cfg']['NavigationTreeDisableDatabaseExpansion']) {
+                    $retval .= "<a class='expander$loaded$container'";
+                } else {
+                    $retval .= "<a";
+                    $icon = "";
+                }
                 $retval .= " href='#'>";
                 $retval .= "<span class='hide aPath'>";
                 $retval .= $paths['aPath'];
@@ -901,7 +942,7 @@ class PMA_NavigationTree
             if ($parent[0]->type == Node::CONTAINER
                 && (in_array($parent[0]->real_name, $haveAjax) || $isNewView)
             ) {
-                $linkClass = ' class="ajax"';
+                $linkClass = ' ajax';
             }
 
             if ($node->type == Node::CONTAINER) {
@@ -915,7 +956,12 @@ class PMA_NavigationTree
                         $args[] = urlencode($parent->real_name);
                     }
                     $link = vsprintf($node->links['icon'], $args);
-                    $retval .= "<a$linkClass href='$link'>{$node->icon}</a>";
+                    if ($linkClass != '') {
+                        $retval .= "<a class='$linkClass' href='$link'>";
+                        $retval .= "{$node->icon}</a>";
+                    } else {
+                        $retval .= "<a href='$link'>{$node->icon}</a>";
+                    }
                 } else {
                     $retval .= "<u>{$node->icon}</u>";
                 }
@@ -928,21 +974,22 @@ class PMA_NavigationTree
                 }
                 $link = vsprintf($node->links['text'], $args);
                 if ($node->type == Node::CONTAINER) {
-                    $retval .= "<a href='$link'>";
+                    $retval .= "&nbsp;<a class='hover_show_full' href='$link'>";
                     $retval .= htmlspecialchars($node->name);
                     $retval .= "</a>";
                 } else {
-                    $retval .= "<a$linkClass href='$link'>";
+                    $retval .= "<a class='hover_show_full$linkClass' href='$link'>";
                     $retval .= htmlspecialchars($node->real_name);
                     $retval .= "</a>";
                 }
             } else {
-                $retval .= "{$node->name}";
+                $retval .= "&nbsp;{$node->name}";
             }
             if ($node->type == Node::CONTAINER) {
                 $retval .= "</i>";
             }
             $retval .= $node->getHtmlForControlButtons();
+            $retval .= '<div class="clearfloat"></div>';
             $wrap = true;
         } else {
             $node->visible = true;
@@ -958,8 +1005,8 @@ class PMA_NavigationTree
             $children = $node->children;
             usort($children, array('PMA_NavigationTree', 'sortNode'));
             $buffer = '';
-            for ($i=0; $i<count($children); $i++) {
-                if ($i + 1 != count($children)) {
+            for ($i=0, $nbChildren = count($children); $i < $nbChildren; $i++) {
+                if ($i + 1 != $nbChildren) {
                     $buffer .= $this->_renderNode(
                         $children[$i],
                         true,
@@ -1031,8 +1078,8 @@ class PMA_NavigationTree
             $retval .= '<li class="fast_filter db_fast_filter">';
             $retval .= '<form class="ajax fast_filter">';
             $retval .= PMA_getHiddenFields($url_params);
-            $retval .= '<input class="searchClause" name="searchClause"';
-            $retval .= ' accesskey="q"';
+            $retval .= '<input class="searchClause" type="text"';
+            $retval .= ' name="searchClause" accesskey="q"';
             // allow html5 placeholder attribute
             $placeholder_key = 'value';
             if (PMA_USR_BROWSER_AGENT !== 'IE'
@@ -1067,7 +1114,8 @@ class PMA_NavigationTree
             $retval .= "<li class='fast_filter'>";
             $retval .= "<form class='ajax fast_filter'>";
             $retval .= PMA_getHiddenFields($url_params);
-            $retval .= "<input class='searchClause' name='searchClause2'";
+            $retval .= "<input class='searchClause' type='text'";
+            $retval .= " name='searchClause2'";
             // allow html5 placeholder attribute
             $placeholder_key = 'value';
             if (PMA_USR_BROWSER_AGENT !== 'IE'
@@ -1102,7 +1150,7 @@ class PMA_NavigationTree
                  array('server' => $GLOBALS['server']),
                  'navigation.php',
                  'frame_navigation',
-                 $GLOBALS['cfg']['MaxNavigationItems'],
+                 $GLOBALS['cfg']['FirstLevelNavigationItems'],
                  'pos',
                  array('dbselector')
              );
@@ -1162,5 +1210,24 @@ class PMA_NavigationTree
             return strcasecmp($a->name, $b->name);
         }
     }
+
+    /**
+     * Display quick warp links, contain Recents and Favorites
+     *
+     * @return string HTML code
+     */
+    private function _quickWarp()
+    {
+        $retval  = '<div id="pma_quick_warp">';
+        if ($GLOBALS['cfg']['NumRecentTables'] > 0) {
+            $retval .= PMA_RecentFavoriteTable::getInstance('recent')->getHtml();
+        }
+        if ($GLOBALS['cfg']['NumFavoriteTables'] > 0) {
+            $retval .= PMA_RecentFavoriteTable::getInstance('favorite')->getHtml();
+        }
+        $retval .= '<div class="clearfloat"></div>';
+        $retval .= '</div>';
+        return $retval;
+    }
 }
 ?>
