@@ -38,9 +38,9 @@ function PMA_getNameAndTypeOfTheColumns($db, $table)
 /**
  * Function to handle the creation or edit of an index
  *
- * @param string $db    current db
- * @param string $table current table
- * @param Object $index current index
+ * @param string    $db    current db
+ * @param string    $table current table
+ * @param PMA_Index $index current index
  *
  * @return void
  */
@@ -53,7 +53,7 @@ function PMA_handleCreateOrEditIndex($db, $table, $index)
     if (! $error) {
         $GLOBALS['dbi']->query($sql_query);
         $message = PMA_Message::success(
-            __('Table %1$s has been altered successfully')
+            __('Table %1$s has been altered successfully.')
         );
         $message->addParam($table);
 
@@ -66,7 +66,6 @@ function PMA_handleCreateOrEditIndex($db, $table, $index)
                 PMA_Util::getMessage(null, $sql_query)
             );
         } else {
-            $active_page = 'tbl_structure.php';
             include 'tbl_structure.php';
         }
         exit;
@@ -81,10 +80,10 @@ function PMA_handleCreateOrEditIndex($db, $table, $index)
 /**
  * Function to get the sql query for index creation or edit
  *
- * @param string $db     current db
- * @param string $table  current table
- * @param Object $index  current index
- * @param bool   &$error whether error occoured or not
+ * @param string    $db     current db
+ * @param string    $table  current table
+ * @param PMA_Index $index  current index
+ * @param bool      &$error whether error occoured or not
  *
  * @return string
  */
@@ -179,7 +178,7 @@ function PMA_prepareFormValues($db, $table)
 /**
  * Function to get the number of fields for the form
  *
- * @param Object $index index
+ * @param PMA_Index $index index
  *
  * @return int
  */
@@ -231,10 +230,10 @@ function PMA_getFormParameters($db, $table)
 /**
  * Function to get html for displaying the index form
  *
- * @param array  $fields      fields
- * @param Object $index       index
- * @param array  $form_params form parameters
- * @param int    $add_fields  number of fields in the form
+ * @param array     $fields      fields
+ * @param PMA_Index $index       index
+ * @param array     $form_params form parameters
+ * @param int       $add_fields  number of fields in the form
  *
  * @return string
  */
@@ -324,6 +323,7 @@ function PMA_getHtmlForIndexForm($fields, $index, $form_params, $add_fields)
         'multilinestring', 'multipolygon', 'geomtrycollection'
     );
     $html .= '<tbody>';
+    /* @var $column PMA_Index_Column */
     foreach ($index->getColumns() as $column) {
         $html .= '<tr class="';
         $html .= $odd_row ? 'odd' : 'even';
@@ -403,4 +403,4 @@ function PMA_getHtmlForIndexForm($fields, $index, $form_params, $add_fields)
 
     return $html;
 }
-?>
\ No newline at end of file
+?>
